@@ -588,3 +588,32 @@ def test_render_file_stdout():
 
             main()
             eq_(fake_stdout.getvalue(), "world\n")
+
+
+def test_custom_jinja2_filters_tests():
+    config_file = "config.yaml"
+    with open(config_file, "w") as f:
+        f.write("hello: world")
+    template_file = "t.jj2"
+    with open(template_file, "w") as f:
+        f.write("{{hello}}")
+    test_args = [
+        "moban",
+        "-e",
+        "jinja2=filter:moban.externals.file_system.url_join",
+        "jinja2=test:moban.externals.file_system.exists",
+        "jinja2=global:description=moban.constants.PROGRAM_DESCRIPTION",
+        "-t",
+        "{{'a'|url_join('b')}} {{'b' is exists}}{{ description }}",
+    ]
+    with patch.object(sys, "argv", test_args):
+        with patch("sys.stdout", new_callable=StringIO) as fake_stdout:
+            from moban.main import main
+
+            expected_output = (
+                "a/b False"
+                + "Static text generator using "
+                + "any template, any data and any location.\n"
+            )
+            main()
+            eq_(fake_stdout.getvalue(), expected_output)
